@@ -1,9 +1,8 @@
-library(ggplot2)
-library(rlang)
-
-# the following code is copied and modified from ggplot2
-# under the R/aes.R file (under MIT license, like this package)
-rename_aes <- function(x) {
+# the following code is copied and modified from ggplot2under the R/aes.R file
+# (under MIT license, like this package) It just implements the soft deprecated
+# `aes_string()` function as `apotc_aes_string()`
+# 
+apotc_rename_aes <- function(x) {
   names(x) <- ggplot2::standardise_aes_names(names(x))
   duplicated_names <- names(x)[duplicated(names(x))]
   if (length(duplicated_names) > 0L) {
@@ -12,7 +11,7 @@ rename_aes <- function(x) {
   x
 }
 
-aes_string <- function(x, y, ...) {
+apotc_aes_string <- function(x, y, ...) {
   mapping <- list(...)
   if (!missing(x)) mapping["x"] <- list(x)
   if (!missing(y)) mapping["y"] <- list(y)
@@ -22,5 +21,5 @@ aes_string <- function(x, y, ...) {
       x <- rlang::parse_expr(x)
     }
   })
-  structure(rename_aes(mapping), class = "uneval")
+  structure(apotc_rename_aes(mapping), class = "uneval")
 }
\ No newline at end of file
