@@ -1,5 +1,4 @@
 source("testdata/SCIP.R")
-library(data.table)
 
 untable <- function(a) {
   as.numeric(unname(a))
@@ -24,4 +23,12 @@ test_that("count_clone_sizes works", {
   expect_equal(length(trial), 2)
   expect_equal(untable(trial[[1]]), c(12,12,2,2))
   expect_equal(untable(trial[[2]]), c(10,7,2))
-})
\ No newline at end of file
+})
+
+test_that("get_transformed_clone_sizes works", {
+  sizelist <- list(c(1,1,2), NULL, c(0.5,3))
+  expect_equal(
+    get_transformed_clone_sizes(sizelist, 0.5, 3),
+    list(c(0.5, 0.5, sqrt(2)*0.5), list(), c(sqrt(0.5)*0.5, sqrt(3)*0.5))
+  )
+})
